@@ -13,7 +13,7 @@ use rstest::rstest;
 use heron_core::*;
 use heron_rapier::convert::IntoBevy;
 use heron_rapier::rapier::dynamics::{IntegrationParameters, RigidBodySet};
-use heron_rapier::{BodyHandle, RapierPlugin};
+use heron_rapier::RapierPlugin;
 
 fn test_app() -> App {
     let mut builder = App::build();
@@ -44,7 +44,8 @@ fn body_is_created_with_velocity() {
         .insert_bundle((
             Transform::default(),
             GlobalTransform::default(),
-            Body::Sphere { radius: 1.0 },
+            RigidBody::Dynamic,
+            CollisionShape::Sphere { radius: 1.0 },
             Velocity { linear, angular },
         ))
         .id();
@@ -53,9 +54,7 @@ fn body_is_created_with_velocity() {
 
     let bodies = app.world.get_resource::<RigidBodySet>().unwrap();
 
-    let body = bodies
-        .get(app.world.get::<BodyHandle>(entity).unwrap().rigid_body())
-        .unwrap();
+    let body = bodies.get(*app.world.get(entity).unwrap()).unwrap();
 
     let actual_linear = (*body.linvel()).into_bevy();
 
@@ -82,7 +81,8 @@ fn velocity_may_be_added_after_creating_the_body() {
         .insert_bundle((
             Transform::default(),
             GlobalTransform::default(),
-            Body::Sphere { radius: 1.0 },
+            RigidBody::Dynamic,
+            CollisionShape::Sphere { radius: 1.0 },
         ))
         .id();
 
@@ -99,9 +99,7 @@ fn velocity_may_be_added_after_creating_the_body() {
 
     let bodies = app.world.get_resource::<RigidBodySet>().unwrap();
 
-    let body = bodies
-        .get(app.world.get::<BodyHandle>(entity).unwrap().rigid_body())
-        .unwrap();
+    let body = bodies.get(*app.world.get(entity).unwrap()).unwrap();
 
     let actual_linear = (*body.linvel()).into_bevy();
     assert_eq!(linear.x, actual_linear.x);
@@ -130,7 +128,8 @@ fn velocity_is_updated_to_reflect_rapier_world() {
         .insert_bundle((
             Transform::default(),
             GlobalTransform::default(),
-            Body::Sphere { radius: 1.0 },
+            RigidBody::Dynamic,
+            CollisionShape::Sphere { radius: 1.0 },
             Velocity::default(),
             Acceleration::from_linear(linear).with_angular(angular),
         ))
@@ -155,10 +154,10 @@ fn velocity_is_updated_to_reflect_rapier_world() {
 }
 
 #[rstest]
-#[case(Some(BodyType::Dynamic))]
-#[case(Some(BodyType::Kinematic))]
+#[case(Some(RigidBody::Dynamic))]
+#[case(Some(RigidBody::Kinematic))]
 #[case(None)]
-fn velocity_can_move_kinematic_bodies(#[case] body_type: Option<BodyType>) {
+fn velocity_can_move_kinematic_bodies(#[case] body_type: Option<RigidBody>) {
     let mut app = test_app();
     let translation = Vec3::new(1.0, 2.0, 3.0);
     let rotation = Quat::from_axis_angle(Vec3::Z, PI / 2.0);
@@ -167,7 +166,8 @@ fn velocity_can_move_kinematic_bodies(#[case] body_type: Option<BodyType>) {
         .world
         .spawn()
         .insert_bundle((
-            Body::Sphere { radius: 2.0 },
+            RigidBody::Dynamic,
+            CollisionShape::Sphere { radius: 2.0 },
             Transform::default(),
             GlobalTransform::default(),
             Velocity::from(translation).with_angular(rotation.into()),
